summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDave Beckett <dave@dajobe.org>2010-01-28 16:37:49 -0800
committerDave Beckett <dave@dajobe.org>2010-01-28 16:37:49 -0800
commit6daf4dbdffe5d4141a20cacb75939d30166b2015 (patch)
treeacb2c65dc4c67298eac1f1ef1121526c9a4c0663
parentc5fa5ba07d3d1dbd567e78c29ae8e1b1b10be02d (diff)
downloadraptor-6daf4dbdffe5d4141a20cacb75939d30166b2015.tar.gz
Update build environment to latest autogen.sh - enable shave for maintainer
-rw-r--r--.gitignore6
-rwxr-xr-xautogen.sh24
-rw-r--r--configure.ac3
-rw-r--r--tests/.gitignore1
4 files changed, 14 insertions, 20 deletions
diff --git a/.gitignore b/.gitignore
index b253b14e..81179511 100644
--- a/.gitignore
+++ b/.gitignore
@@ -24,19 +24,13 @@ autom4te.cache
bugs
compile
config.cache
-config.guess
config.log
config.status
-config.sub
configure
-depcomp
dmalloc*
example?
gtk-doc.make
-install-sh
libtool
-ltmain.sh
-missing
mkinstalldirs
not-used
old
diff --git a/configure.ac b/configure.ac
index 8dd90511..b3a68da4 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1265,6 +1265,9 @@ AC_SUBST(abs_top_srcdir)
abs_top_builddir=`pwd`
AC_SUBST(abs_top_builddir)
+dnl automake 1.11
+AM_SILENT_RULES([no])
+
AC_CONFIG_FILES([Makefile
raptor.spec
raptor.rdf
diff --git a/tests/.gitignore b/tests/.gitignore
index 46ed666f..a564cf26 100644
--- a/tests/.gitignore
+++ b/tests/.gitignore
@@ -1,4 +1,3 @@
-*.out
.deps
.libs
TAGS
diff --git a/autogen.sh b/autogen.sh
index 0859d596..44de7ae4 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -45,7 +45,8 @@ CONFIG_DIR=${CONFIG_DIR-../config}
# Set an envariable of the same name in uppercase, to override scan
#
programs="automake aclocal autoconf autoheader libtoolize"
-confs=`find . -name configure.ac -print`
+confs=`find . -name configure.ac -print | grep -v /releases/`
+
gtkdoc_args=
if grep "^GTK_DOC_CHECK" $confs >/dev/null; then
programs="$programs gtkdocize"
@@ -58,20 +59,16 @@ ltdl_args=
if grep "^AC_LIBLTDL_" $confs >/dev/null; then
ltdl_args="--ltdl"
fi
-shave_args=
-if grep "^SHAVE_INIT" $confs >/dev/null; then
- shave_args="--enable-shave"
+silent_args=
+if grep "^AM_SILENT_RULES" $confs >/dev/null; then
+ silent_args="--enable-silent-rules"
fi
# Some dependencies for autotools:
-# automake 1.11 requires autoconf 2.62
-# automake 1.10 requires autoconf 2.60
-# automake 1.9 requires autoconf 2.58
-# automake 1.8 requires autoconf 2.58
-# automake 1.7 requires autoconf 2.54
-automake_min_vers=010700
+# automake 1.11 requires autoconf 2.62 (needed for AM_SILENT_RULES)
+automake_min_vers=011100
aclocal_min_vers=$automake_min_vers
-autoconf_min_vers=025400
+autoconf_min_vers=026200
autoheader_min_vers=$autoconf_min_vers
libtoolize_min_vers=020200
gtkdocize_min_vers=010300
@@ -83,7 +80,8 @@ aclocal_args=
autoconf_args=
libtoolize_args="--force --copy --automake $ltdl_args"
gtkdocize_args="--copy"
-configure_args="--enable-maintainer-mode $gtkdoc_args $shave_args"
+# --enable-gtk-doc does no harm if it's not available
+configure_args="--enable-maintainer-mode $gtkdoc_args $silent_args"
# You should not need to edit below here
@@ -278,7 +276,7 @@ if test -d $CONFIG_DIR; then
fi
-for coin in `find $SRCDIR -name configure.ac -print`
+for coin in `find $SRCDIR -name configure.ac -print | grep -v /releases/`
do
dir=`dirname $coin`
if test -f "$dir/NO-AUTO-GEN"; then